/* This file is part of the Connector Framework
 * Copyright (C) 2008-2013 Index Data
 * See the file LICENSE for details.
 */

/** \file
 * \brief RPN to CF queries (JSON based)
 */

#include <yaz/wrbuf.h>
#include <yaz/z-core.h>

int cf_database_args(const char *url_arg,
                     ODR odr,
                     char **subdatabase,
                     const char **proxy, const char **loglevel,
                     WRBUF result,
                     const char *default_user,
                     const char *default_password);

/*
 * Local variables:
 * c-basic-offset: 4
 * c-file-style: "Stroustrup"
 * indent-tabs-mode: nil
 * End:
 * vim: shiftwidth=4 tabstop=8 expandtab
 */
